@@ -1,4 +1,4 @@
-/* $Id: winX.c,v 5.0 2001/04/07 20:00:59 dik Exp $
+/* $Id: winX.c,v 5.2 2001/05/27 20:37:11 dik Exp $
  *
  * XPilot, a multiplayer gravity war game.  Copyright (C) 1991-2001 by
  *
@@ -28,7 +28,7 @@
 *  This file is mostly Win32 translations of the X calls that xpilot uses.	*
 *  Anything starting with WinX is a special wedge function that i needed	*
 *																			*
-*  $Id: winX.c,v 5.0 2001/04/07 20:00:59 dik Exp $						*
+*  $Id: winX.c,v 5.2 2001/05/27 20:37:11 dik Exp $						*
 \***************************************************************************/
 #include "winX.h"
 #include "windows.h"
@@ -321,7 +321,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x_root	= pt.x;
 			button->y_root	= pt.y;
 			button->button	= Button1;
-			xevent(event);
+			win_xevent(event);
 		}
 		return DefWindowProc(hwnd, uMsg, wParam, lParam);
 	}
@@ -340,7 +340,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x		= LOWORD(lParam);
 			button->y		= HIWORD(lParam);
 			button->button	= Button1;
-			if (xevent(event) == -1)
+			if (win_xevent(event) == -1)
 			{
 				WinXExit();
 			}
@@ -368,7 +368,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x_root	= pt.x;
 			button->y_root	= pt.y;
 			button->button	= Button2;
-			xevent(event);
+			win_xevent(event);
 		}
 		return DefWindowProc(hwnd, uMsg, wParam, lParam);
 	}
@@ -387,7 +387,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x		= LOWORD(lParam);
 			button->y		= HIWORD(lParam);
 			button->button	= Button2;
-			if (xevent(event) == -1)
+			if (win_xevent(event) == -1)
 			{
 				WinXExit();
 			}
@@ -415,7 +415,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x_root	= pt.x;
 			button->y_root	= pt.y;
 			button->button	= Button3;
-			xevent(event);
+			win_xevent(event);
 		}
 		return DefWindowProc(hwnd, uMsg, wParam, lParam);
 	}
@@ -434,7 +434,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			button->x		= LOWORD(lParam);
 			button->y		= HIWORD(lParam);
 			button->button	= Button3;
-			if (xevent(event) == -1)
+			if (win_xevent(event) == -1)
 			{
 				WinXExit();
 			}
@@ -449,8 +449,8 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 		XID		i;
 		XAnyEvent*	enter = (XAnyEvent*)&event;
 
-		Trace("MouseMove in %d %d/%d %s:%d\n", xidno, 
-			LOWORD(lParam), HIWORD(lParam), xid[xidno].any.file, xid[xidno].any.line);
+		/* Trace("MouseMove in %d %d/%d %s:%d\n", xidno, 
+			LOWORD(lParam), HIWORD(lParam), xid[xidno].any.file, xid[xidno].any.line); */
 
 		enter->type			= LeaveNotify;
 		for (i=0; i<MAX_XIDS; i++)
@@ -460,7 +460,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			{
 				Trace("LeaveNotify %d %s:%d\n", xidno, xid[xidno].any.file, xid[xidno].any.line);
 				enter->window = i;
-				xevent(event);
+				win_xevent(event);
 				xid[i].hwnd.mouseover = FALSE;
 			}
 		}
@@ -473,7 +473,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 			me->y = HIWORD(lParam);
 //			if (me->x != draw_width/2 && me->y != draw_height/2)
 			{
-				xevent(event);
+				win_xevent(event);
 //				SetCursorPos(draw_width/2, draw_height/2);
 			}
 		//	return(0);
@@ -485,7 +485,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 				Trace("EnterNotify %d %s:%d\n", xidno, xid[xidno].any.file, xid[xidno].any.line);
 				enter->type			= EnterNotify;
 				enter->window		= xidno;
-				xevent(event);
+				win_xevent(event);
 			}
 			xid[xidno].hwnd.mouseover = TRUE;
 		}
@@ -548,7 +548,7 @@ LRESULT	CALLBACK	WinXwindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lPar
 							expose->height	= rect.bottom-rect.top;
 							expose->count	= 0;
 							Trace("Expose %d %s:%d\n", xidno, xid[xidno].any.file, xid[xidno].any.line);
-							xevent(event);
+							win_xevent(event);
 						}
 						if (bHasPal)
 						{
@@ -612,7 +612,7 @@ LRESULT CALLBACK MouseHook(int nCode, WPARAM wParam, LPARAM lParam)
 	me->window = draw;
 	me->x = ((MOUSEHOOKSTRUCT*)lParam)->pt.x;
 	me->y = ((MOUSEHOOKSTRUCT*)lParam)->pt.y;
-	xevent(event);
+	win_xevent(event);
 
 	return(1);
 
